@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 2001--2022 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 2001--2023 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -63,8 +63,7 @@ Accidental_interface::horizontal_skylines (SCM smob)
 
   SCM parenthesized = get_property (me, "parenthesized");
 
-  std::string glyph_name
-    = robust_scm2string (get_property (me, "glyph-name"), "");
+  string glyph_name = ly_scm2string (get_property (me, "glyph-name"));
 
   if ((glyph_name == "accidentals.flat" || glyph_name == "accidentals.flatflat")
       && !from_scm<bool> (parenthesized))
@@ -124,8 +123,7 @@ Accidental_interface::print (SCM smob)
 {
   auto *const me = LY_ASSERT_SMOB (Grob, smob, 1);
   Font_metric *fm = Font_interface::get_default_font (me);
-  std::string glyph_name
-    = robust_scm2string (get_property (me, "glyph-name"), "");
+  std::string glyph_name = ly_scm2string (get_property (me, "glyph-name"));
   Stencil st = fm->find_by_name (glyph_name);
   if (st.is_empty ())
     me->warning (_f ("cannot find glyph %s", glyph_name));
