@@ -369,7 +369,8 @@ Beam::get_accidentals (Grob *me)
           extract_grob_set (last_stem, "note-heads", note_heads);
           for (auto &note_head : note_heads)
             {
-              if (Grob *acc = unsmob<Grob> (get_object (note_head, "accidental-grob")))
+              if (Grob *acc
+                  = unsmob<Grob> (get_object (note_head, "accidental-grob")))
                 accs.push_back (acc);
             }
         }
@@ -385,23 +386,22 @@ Beam::get_gaps (Grob *me, Grob *commonx)
   Drul_array<Real> gap_lengths (gap_length, gap_length);
 
   if ((Stem::duration_log (stems[0])) <= 0)
-      {
-        vector<Grob *> accs = get_accidentals (me);
+    {
+      vector<Grob *> accs = get_accidentals (me);
 
-        if (!accs.empty ())
-          {
-            Interval accs_ext
-              = Axis_group_interface::relative_group_extent (accs, commonx,
-                                                              X_AXIS);
-            if (!accs_ext.is_empty ())
-              {
-                Real accs_length = accs_ext.length ();
-                Real acc_padding 
-                  = from_scm (get_property (me, "accidental-padding"), 1.0);
-                gap_lengths[RIGHT] += accs_length + acc_padding;
-              }
-          }
-      }
+      if (!accs.empty ())
+        {
+          Interval accs_ext = Axis_group_interface::relative_group_extent (
+            accs, commonx, X_AXIS);
+          if (!accs_ext.is_empty ())
+            {
+              Real accs_length = accs_ext.length ();
+              Real acc_padding
+                = from_scm (get_property (me, "accidental-padding"), 1.0);
+              gap_lengths[RIGHT] += accs_length + acc_padding;
+            }
+        }
+    }
   return gap_lengths;
 }
 
@@ -551,8 +551,8 @@ Beam::calc_beam_segments (SCM smob)
 
               bool event = on_beam_bound
                            || absdiff (seg.rank_, segs[j + event_dir].rank_) > 1
-                           || (abs (vertical_count) >= seg.max_connect_
-                               || abs (vertical_count)
+                           || (std::abs (vertical_count) >= seg.max_connect_
+                               || std::abs (vertical_count)
                                     >= segs[j + event_dir].max_connect_);
 
               if (!event)
@@ -610,7 +610,8 @@ Beam::calc_beam_segments (SCM smob)
                   current.horizontal_[event_dir] += event_dir * seg.width_ / 2;
                   if (seg.gapped_)
                     {
-                      current.horizontal_[event_dir] -= event_dir * gap_lengths[event_dir];
+                      current.horizontal_[event_dir]
+                        -= event_dir * gap_lengths[event_dir];
 
                       if (Stem::is_invisible (seg.stem_))
                         {
@@ -625,7 +626,7 @@ Beam::calc_beam_segments (SCM smob)
                               = event_dir
                                 * std::min (
                                   event_dir * current.horizontal_[event_dir],
-                                  - gap_lengths[event_dir] / 2
+                                  -gap_lengths[event_dir] / 2
                                     + event_dir
                                         * heads[k]->extent (
                                           commonx, X_AXIS)[-event_dir]);
@@ -903,7 +904,7 @@ Beam::get_default_dir (Grob *me)
 
   if (!force_dir)
     {
-      if (abs (extremes[UP]) > -extremes[DOWN])
+      if (std::abs (extremes[UP]) > -extremes[DOWN])
         return DOWN;
       else if (extremes[UP] < -extremes[DOWN])
         return UP;
@@ -1279,7 +1280,7 @@ Beam::forced_stem_count (Grob *me)
       Direction defdir
         = from_scm<Direction> (get_property (s, "default-direction"));
 
-      if (abs (Stem::chord_start_y (s)) > 0.1 && defdir
+      if (std::abs (Stem::chord_start_y (s)) > 0.1 && defdir
           && get_grob_direction (s) != defdir)
         f++;
     }
