@@ -1,6 +1,6 @@
 ;;;; This file is part of LilyPond, the GNU music typesetter.
 ;;;;
-;;;; Copyright (c) 1998--2022 Han-Wen Nienhuys <hanwen@xs4all.nl>,
+;;;; Copyright (c) 1998--2023 Han-Wen Nienhuys <hanwen@xs4all.nl>,
 ;;;;                          Jan Nieuwenhuizen <janneke@gnu.org>
 ;;;;
 ;;;; LilyPond is free software: you can redistribute it and/or modify
@@ -115,18 +115,16 @@ way the transposition number is displayed."
               #f))
          (count-markup (cond ((number? count)
                               (if (> count 0)
-                                  (make-simple-markup
-                                   (number->string count))
+                                  (number->string count)
                                   #f))
                              ((pair? count)
                               ;; Thin Spaces U+2009 & En-dash U+2013
-                              (make-simple-markup
-                               (format #f "~a – ~a" (car count) (cdr count))))
+                              (format #f "~a – ~a" (car count) (cdr count)))
                              (else #f)))
          (note-markup (if (and (not hide-note) count-markup)
                           (list
                            (make-general-align-markup Y DOWN note-mark)
-                           (make-simple-markup " = ")
+                           " = "
                            count-markup)
                           #f))
          (text-markup (if (not (null? text)) (make-bold-markup text) #f)))
@@ -134,9 +132,9 @@ way the transposition number is displayed."
         (if (and note-markup (not hide-note))
             (make-line-markup (list (make-concat-markup
                                      (append (list text-markup
-                                                   (make-simple-markup " ("))
+                                                   " (")
                                              note-markup
-                                             (list (make-simple-markup ")"))))))
+                                             (list ")")))))
             (make-line-markup (list text-markup)))
         (if note-markup
             (make-line-markup (list (make-concat-markup note-markup)))
@@ -413,6 +411,19 @@ segni to avoid ambiguity."
                  CENTER alt-markup))
           (set! alt-markup #f)))
 
+    ;; We treat a solitary plus similarly to digits (but enlarged).
+    (if (and (not fig-markup) plus-markup)
+        (begin
+          (set! fig-markup
+                (make-align-on-other-markup
+                 Y
+                 CENTER (make-number-markup "1")
+                 CENTER (make-align-on-other-markup
+                         X
+                         CENTER (make-number-markup "1")
+                         CENTER (make-fontsize-markup 3 plus-markup))))
+          (set! plus-markup #f)))
+
     ;; The alteration gets attached either to the left or the right of
     ;; the digit(s).
     (if alt-markup
